==> dcoupon_sdk_flutter_package-2.0.0.tar.gz: lib/src/presentation/screens/enrollment_form_screen.dart <==
import 'package:dcoupon_sdk_flutter_package/src/domain/entities/enrollment_form.dart';
import 'package:dcoupon_sdk_flutter_package/src/presentation/colors.dart';
import 'package:dcoupon_sdk_flutter_package/src/presentation/screens/enrollment_form_html_widget.dart';
import 'package:dcoupon_sdk_flutter_package/src/themes/dark_theme.dart';
import 'package:dcoupon_sdk_flutter_package/src/themes/light_theme.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/constants.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/translations.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';

class EnrollmentFormScreen extends StatefulWidget {
  final EnrollmentForm enrollmentForm;
  final VoidCallback onCloseEnrollment;
  final VoidCallback onAcceptEnrollment;

  EnrollmentFormScreen({
    Key key,
    this.enrollmentForm,
    this.onCloseEnrollment,
    this.onAcceptEnrollment,
  }) : super(key: key);

  @override
  _EnrollmentFormScreenState createState() => _EnrollmentFormScreenState();
}

class _EnrollmentFormScreenState extends State<EnrollmentFormScreen> {
  var _touOpened = false;
  var _ppOpened = false;
  var _checkboxIsSelected = false;
  var _isLoading = false;

  var legalTextPP, legalTextTOU;
  List<dynamic> legalDocumentsToAccept = <dynamic>[];

  @override
  void initState() {
    super.initState();

    legalTextPP = widget.enrollmentForm.legalDocumentsList
        .firstWhere((element) => element.docType == Constants.PP)
        .legalText;
    legalTextTOU = widget.enrollmentForm.legalDocumentsList
        .firstWhere((element) => element.docType == Constants.TOU)
        .legalText;
  }

  void closeEnrollment() {
    widget.onCloseEnrollment();
  }

  @override
  Widget build(BuildContext context) {
    final importantStyle = TextStyle(fontWeight: FontWeight.bold);
    return Scaffold(
        appBar: AppBar(
          centerTitle: true,
          elevation: 0,
          bottom: PreferredSize(
            child: Container(
              color: Theme.of(context).textTheme.bodyText2.color,
              height: 0.2,
            ),
            preferredSize: Size.fromHeight(0.2),
          ),
          title: new Image(
            fit: BoxFit.scaleDown,
            height: 40,
            image: new AssetImage(
              'lib/assets/images/dcoupon_logo.png',
              package: 'dcoupon_sdk_flutter_package',
            ),
          ),
          leading: BackButton(
            onPressed: () {
              closeEnrollment();
            },
          ),
        ),
        body: Builder(
          builder: (context) => Stack(
            children: [
              NotificationListener<OverscrollIndicatorNotification>(
                onNotification: (OverscrollIndicatorNotification overscroll) {
                  overscroll.disallowGlow();
                },
                child: ListView(
                  padding: EdgeInsets.all(32.0),
                  children: <Widget>[
                    Text(Translations.of(context)
                        .text('dcoupon_mandatory_documents')),
                    SizedBox(
                      height: 32,
                    ),
                    GestureDetector(
                      onTap: () {
                        _showTOUDialog();
                      },
                      child: Container(
                        padding: EdgeInsets.all(16.0),
                        decoration: BoxDecoration(
                          border: Border.all(
                            color: DCouponColors.dCouponPrimaryOrange,
                          ),
                          borderRadius: BorderRadius.circular(10.0),
                        ),
                        width: double.infinity,
                        child: Row(
                          mainAxisAlignment: MainAxisAlignment.center,
                          children: <Widget>[
                            Icon(Icons.assignment),
                            SizedBox(width: 8),
                            Text(Translations.of(context)
                                .text('dcoupon_legal_tou')
                                .toUpperCase())
                          ],
                        ),
                      ),
                    ),
                    SizedBox(
                      height: 16,
                    ),
                    GestureDetector(
                      onTap: () {
                        _showPPDialog();
                      },
                      child: Container(
                        padding: EdgeInsets.all(16.0),
                        decoration: BoxDecoration(
                          border: Border.all(
                            color: DCouponColors.dCouponPrimaryOrange,
                          ),
                          borderRadius: BorderRadius.circular(6.0),
                        ),
                        width: double.infinity,
                        child: Row(
                          mainAxisAlignment: MainAxisAlignment.center,
                          children: <Widget>[
                            Icon(Icons.assignment),
                            SizedBox(width: 8),
                            Text(Translations.of(context)
                                .text('dcoupon_legal_pp')
                                .toUpperCase()),
                            SizedBox(width: 8),
                          ],
                        ),
                      ),
                    ),
                    SizedBox(
                      height: 24,
                    ),
                    Row(
                      children: <Widget>[
                        Checkbox(
                          value: _checkboxIsSelected,
                          onChanged: (bool value) {
                            if (_touOpened && _ppOpened) {
                              setState(() {
                                _checkboxIsSelected = value;
                              });
                            } else {
                              Scaffold.of(context)
                                ..hideCurrentSnackBar()
                                ..showSnackBar(
                                  SnackBar(
                                    content: Row(
                                      mainAxisAlignment:
                                          MainAxisAlignment.spaceBetween,
                                      children: [
                                        Flexible(
                                          child: Text(Translations.of(context)
                                              .text(
                                                  'dcoupon_terms_mustBeRead')),
                                        ),
                                        Icon(
                                          Icons.error,
                                          color: Theme.of(context)
                                              .snackBarTheme
                                              .contentTextStyle
                                              .color,
                                        ),
                                      ],
                                    ),
                                    backgroundColor:
                                        Theme.of(context).errorColor,
                                  ),
                                );
                            }
                          },
                        ),
                        SizedBox(width: 8),
                        Flexible(
                          child: RichText(
                            text: TextSpan(
                              style: Theme.of(context)
                                  .textTheme
                                  .bodyText2
                                  .copyWith(fontSize: 13),
                              children: <TextSpan>[
                                TextSpan(
                                    text: Translations.of(context)
                                        .text('dcoupon_agreeTo')),
                                TextSpan(text: ' '),
                                TextSpan(
                                  text: Translations.of(context)
                                      .text('dcoupon_legal_tou'),
                                  style: importantStyle,
                                  recognizer: TapGestureRecognizer()
                                    ..onTap = () {
                                      _showTOUDialog();
                                    },
                                ),
                                TextSpan(text: ' '),
                                TextSpan(
                                    text: Translations.of(context)
                                        .text('dcoupon_haveRead')),
                                TextSpan(text: ' '),
                                TextSpan(
                                  text: Translations.of(context)
                                      .text('dcoupon_legal_pp'),
                                  style: importantStyle,
                                  recognizer: TapGestureRecognizer()
                                    ..onTap = () {
                                      _showPPDialog();
                                    },
                                ),
                              ],
                            ),
                          ),
                        ),
                      ],
                    ),
                    SizedBox(
                      height: 8,
                    ),
                    RaisedButton(
                      shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(6.0),
                      ),
                      child: Text(
                          Translations.of(context).text('dcoupon_continue')),
                      onPressed: _checkboxIsSelected
                          ? () {
                              acceptEnrollment();
                            }
                          : null,
                    ),
                  ],
                ),
              ),
              Container(
                child: _isLoading
                    ? Container(
                        color: Colors.grey[200].withAlpha(150),
                        height: MediaQuery.of(context).size.height,
                        child: Center(
                          child: CircularProgressIndicator(),
                        ),
                      )
                    : Container(),
              ),
            ],
          ),
        ));
  }

  void _showDialog(
    String data,
  ) {
    showDialog(
      barrierColor: Colors.black38,
      context: context,
      barrierDismissible: false, // user must tap title or dialog!
      builder: (BuildContext context) {
        return Dialog(
          elevation: 0,
          insetPadding: EdgeInsets.symmetric(horizontal: 24, vertical: 24),
          shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(6.0),
          ),
          backgroundColor: Colors.transparent,
          child: Stack(
            children: [
              EnrollmentFormHtmlWidget(data: data),
              Positioned(
                left: 0.0,
                child: GestureDetector(
                  onTap: () {
                    Navigator.of(context).pop();
                  },
                  child: Align(
                    alignment: Alignment.topRight,
                    child: CircleAvatar(
                      radius: 14.0,
                      backgroundColor:
                          Theme.of(context).scaffoldBackgroundColor,
                      child: Icon(
                        Icons.close,
                        color: Theme.of(context).textTheme.bodyText2.color,
                      ),
                    ),
                  ),
                ),
              ),
            ],
          ),
        );
      },
    );
  }

  void _showTOUDialog() {
    setState(() {
      _touOpened = true;
    });
    _showDialog(legalTextTOU);
  }

  void _showPPDialog() {
    setState(() {
      _ppOpened = true;
    });
    _showDialog(legalTextPP);
  }

  void acceptEnrollment() {
    setState(() {
      _isLoading = true;
    });

    widget.onAcceptEnrollment();
  }
}

==> dcoupon_sdk_flutter_package-4.0.1.tar.gz: lib/src/presentation/screens/enrollment_form_screen.dart <==
import 'package:dcoupon_sdk_flutter_package/src/domain/entities/enrollment_form.dart';
import 'package:dcoupon_sdk_flutter_package/src/presentation/colors.dart';
import 'package:dcoupon_sdk_flutter_package/src/presentation/screens/enrollment_form_html_widget.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/constants.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/translations.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';

class EnrollmentFormScreen extends StatefulWidget {
  final EnrollmentForm? enrollmentForm;
  final VoidCallback? onCloseEnrollment;
  final VoidCallback? onAcceptEnrollment;

  EnrollmentFormScreen({
    Key? key,
    this.enrollmentForm,
    this.onCloseEnrollment,
    this.onAcceptEnrollment,
  }) : super(key: key);

  @override
  _EnrollmentFormScreenState createState() => _EnrollmentFormScreenState();
}

class _EnrollmentFormScreenState extends State<EnrollmentFormScreen> {
  bool? _checkboxIsSelected = false;
  var _isLoading = false;

  var legalTextPP, legalTextTOU;
  List<dynamic> legalDocumentsToAccept = <dynamic>[];

  @override
  void initState() {
    super.initState();

    legalTextPP = widget.enrollmentForm!.legalDocumentsList!
        .firstWhere((element) => element.docType == Constants.PP)
        .legalText;
    legalTextTOU = widget.enrollmentForm!.legalDocumentsList!
        .firstWhere((element) => element.docType == Constants.TOU)
        .legalText;
  }

  void closeEnrollment() {
    widget.onCloseEnrollment!();
  }

  @override
  Widget build(BuildContext context) {
    final importantStyle = TextStyle(fontWeight: FontWeight.bold);
    return Scaffold(
        appBar: AppBar(
          centerTitle: true,
          elevation: 0,
          bottom: PreferredSize(
            child: Container(
              color: Theme.of(context).textTheme.bodyText2!.color,
              height: 0.2,
            ),
            preferredSize: Size.fromHeight(0.2),
          ),
          title: new Image(
            fit: BoxFit.scaleDown,
            height: 40,
            image: new AssetImage(
              'lib/assets/images/dcoupon_logo.png',
              package: 'dcoupon_sdk_flutter_package',
            ),
          ),
          leading: BackButton(
            onPressed: () {
              closeEnrollment();
            },
          ),
        ),
        body: Builder(
          builder: (context) => Stack(
            children: [
              NotificationListener<OverscrollIndicatorNotification>(
                onNotification: (OverscrollIndicatorNotification overscroll) {
                  overscroll.disallowGlow();
                  return false;
                },
                child: ListView(
                  padding: EdgeInsets.all(32.0),
                  children: <Widget>[
                    Text(Translations.of(context)!
                        .text('dcoupon_mandatory_documents')),
                    SizedBox(
                      height: 32,
                    ),
                    GestureDetector(
                      onTap: () {
                        _showTOUDialog();
                      },
                      child: Container(
                        padding: EdgeInsets.all(16.0),
                        decoration: BoxDecoration(
                          border: Border.all(
                            color: DCouponColors.dCouponPrimaryOrange,
                          ),
                          borderRadius: BorderRadius.circular(10.0),
                        ),
                        width: double.infinity,
                        child: Row(
                          mainAxisAlignment: MainAxisAlignment.center,
                          children: <Widget>[
                            Icon(Icons.assignment),
                            SizedBox(width: 8),
                            Text(Translations.of(context)!
                                .text('dcoupon_legal_tou')
                                .toUpperCase())
                          ],
                        ),
                      ),
                    ),
                    SizedBox(
                      height: 16,
                    ),
                    GestureDetector(
                      onTap: () {
                        _showPPDialog();
                      },
                      child: Container(
                        padding: EdgeInsets.all(16.0),
                        decoration: BoxDecoration(
                          border: Border.all(
                            color: DCouponColors.dCouponPrimaryOrange,
                          ),
                          borderRadius: BorderRadius.circular(6.0),
                        ),
                        width: double.infinity,
                        child: Row(
                          mainAxisAlignment: MainAxisAlignment.center,
                          children: <Widget>[
                            Icon(Icons.assignment),
                            SizedBox(width: 8),
                            Text(Translations.of(context)!
                                .text('dcoupon_legal_pp')
                                .toUpperCase()),
                            SizedBox(width: 8),
                          ],
                        ),
                      ),
                    ),
                    SizedBox(
                      height: 24,
                    ),
                    Row(
                      children: <Widget>[
                        Checkbox(
                          value: _checkboxIsSelected,
                          onChanged: (bool? value) {
                            setState(() {
                              _checkboxIsSelected = value;
                            });
                          },
                        ),
                        SizedBox(width: 8),
                        Flexible(
                          child: RichText(
                            text: TextSpan(
                              style: Theme.of(context)
                                  .textTheme
                                  .bodyText2!
                                  .copyWith(fontSize: 13),
                              children: <TextSpan>[
                                TextSpan(
                                    text: Translations.of(context)!
                                        .text('dcoupon_agreeTo')),
                                TextSpan(text: ' '),
                                TextSpan(
                                  text: Translations.of(context)!
                                      .text('dcoupon_legal_tou'),
                                  style: importantStyle,
                                  recognizer: TapGestureRecognizer()
                                    ..onTap = () {
                                      _showTOUDialog();
                                    },
                                ),
                                TextSpan(text: ' '),
                                TextSpan(
                                    text: Translations.of(context)!
                                        .text('dcoupon_haveRead')),
                                TextSpan(text: ' '),
                                TextSpan(
                                  text: Translations.of(context)!
                                      .text('dcoupon_legal_pp'),
                                  style: importantStyle,
                                  recognizer: TapGestureRecognizer()
                                    ..onTap = () {
                                      _showPPDialog();
                                    },
                                ),
                              ],
                            ),
                          ),
                        ),
                      ],
                    ),
                    SizedBox(
                      height: 8,
                    ),
                    ElevatedButton(
                      style: ElevatedButton.styleFrom(
                        shape: RoundedRectangleBorder(
                          borderRadius: BorderRadius.circular(6.0),
                        ),
                      ),
                      child: Text(
                          Translations.of(context)!.text('dcoupon_continue')),
                      onPressed: _checkboxIsSelected!
                          ? () {
                              acceptEnrollment();
                            }
                          : null,
                    ),
                  ],
                ),
              ),
              Container(
                child: _isLoading
                    ? Container(
                        color: Colors.grey[200]!.withAlpha(150),
                        height: MediaQuery.of(context).size.height,
                        child: Center(
                          child: CircularProgressIndicator(),
                        ),
                      )
                    : Container(),
              ),
            ],
          ),
        ));
  }

  void _showDialog(
    String? data,
  ) {
    showDialog(
      barrierColor: Colors.black38,
      context: context,
      barrierDismissible: false, // user must tap title or dialog!
      builder: (BuildContext context) {
        return Dialog(
          elevation: 0,
          insetPadding: EdgeInsets.symmetric(horizontal: 24, vertical: 24),
          shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(6.0),
          ),
          backgroundColor: Colors.transparent,
          child: Stack(
            children: [
              EnrollmentFormHtmlWidget(data: data),
              Positioned(
                left: 0.0,
                child: GestureDetector(
                  onTap: () {
                    Navigator.of(context).pop();
                  },
                  child: Align(
                    alignment: Alignment.topRight,
                    child: CircleAvatar(
                      radius: 14.0,
                      backgroundColor:
                          Theme.of(context).scaffoldBackgroundColor,
                      child: Icon(
                        Icons.close,
                        color: Theme.of(context).textTheme.bodyText2!.color,
                      ),
                    ),
                  ),
                ),
              ),
            ],
          ),
        );
      },
    );
  }

  void _showTOUDialog() {
    _showDialog(legalTextTOU);
  }

  void _showPPDialog() {
    _showDialog(legalTextPP);
  }

  void acceptEnrollment() {
    setState(() {
      _isLoading = true;
    });

    widget.onAcceptEnrollment!();
  }
}
